# pyscarab

[![Travis](https://travis-ci.org/blindstore/pyscarab.svg?branch=master)](https://travis-ci.org/blindstore/pyscarab)

Python wrapper and abstractions for [`libscarab`](https://hcrypt.com/) FHE library

## Installation

Requires libscarab [fork](https://github.com/blindstore/libScarab) installed. If it is present:

```
pip install git+git://github.com/blindstore/pyscarab.git@master
```

